==> haskell-success-0.2.6-282-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 success
version:              0.2.6
visibility:           public
id:                   success-0.2.6-PrSsJLOvCQAboYRZsRvzD
key:                  success-0.2.6-PrSsJLOvCQAboYRZsRvzD
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/success 
synopsis:
    A version of Either specialised for encoding of success or failure

description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.

category:             Data, Failure
abi:                  694e8bc167bb3a20de30a0abe4facf9c
exposed:              True
exposed-modules:      Success.Impure Success.Pure
import-dirs:          /usr/lib/ghc-9.2.8/site-local/success-0.2.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/success-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-success
hs-libraries:         HSsuccess-0.2.6-PrSsJLOvCQAboYRZsRvzD
depends:
    base-4.16.4.0 monad-control-1.0.3.1-CA1GlfSV3Rl4gDTt4Ny2FB
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.6-Jo7hBiquY6Q1je3XsS9imU

haddock-interfaces:   /usr/share/doc/haskell-success/html/success.haddock
haddock-html:         /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-success-0.2.6-292-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 success
version:              0.2.6
visibility:           public
id:                   success-0.2.6-8qqWFZ0IBkM1LF6u1btOB
key:                  success-0.2.6-8qqWFZ0IBkM1LF6u1btOB
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/success 
synopsis:
    A version of Either specialised for encoding of success or failure

description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.

category:             Data, Failure
abi:                  1bc36648a9c848f244402ac2e7157e5e
exposed:              True
exposed-modules:      Success.Impure Success.Pure
import-dirs:          /usr/lib/ghc-9.4.8/site-local/success-0.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/success-0.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/success-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-success
hs-libraries:         HSsuccess-0.2.6-8qqWFZ0IBkM1LF6u1btOB
depends:
    base-4.17.2.1 monad-control-1.0.3.1-Ikmrl0sRfnc3OZUIMD7pV0
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.6-1prsdVngpQ363D7JaNgjBK

haddock-interfaces:   /usr/share/doc/haskell-success/html/success.haddock
haddock-html:         /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
